==> haskell-ansi-wl-pprint-0.6.9-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-wl-pprint
version:              0.6.9
visibility:           public
id:                   ansi-wl-pprint-0.6.9-JwnFI5coIDQ2g5B6f0Shfy
key:                  ansi-wl-pprint-0.6.9-JwnFI5coIDQ2g5B6f0Shfy
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  062ddf5c13ff7830174421dfe87b31a4
exposed:              True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal

import-dirs:          /usr/lib/ghc-8.10.3/site-local/ansi-wl-pprint-0.6.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/ansi-wl-pprint-0.6.9
hs-libraries:         HSansi-wl-pprint-0.6.9-JwnFI5coIDQ2g5B6f0Shfy
depends:
    ansi-terminal-0.11-44uIfdaHXBv5GuKBOXRfhb base-4.14.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.9-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-wl-pprint
version:              0.6.9
visibility:           public
id:                   ansi-wl-pprint-0.6.9-AQ7kFxZdKVQBjntDDY7LVg
key:                  ansi-wl-pprint-0.6.9-AQ7kFxZdKVQBjntDDY7LVg
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  10e6501eb1c4b85ef2a08aaed58acf6a
exposed:              True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal

import-dirs:          /usr/lib/ghc-8.10.3/site-local/ansi-wl-pprint-0.6.9
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/ansi-wl-pprint-0.6.9
hs-libraries:         HSansi-wl-pprint-0.6.9-AQ7kFxZdKVQBjntDDY7LVg
depends:
    ansi-terminal-0.11-DTKwh93dIC85PDoz37LITW base-4.14.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
